@@ -2,12 +2,13 @@
 # License: BSD
 # Copyright: (C) Dmitry Shachnev, 2012
 
+import os
 import sys
-from markups.common import *
+from markups.common import CONFIGURATION_DIR
 from markups.markdown import MarkdownMarkup
 from markups.restructuredtext import ReStructuredTextMarkup
 
-__version__ = '0.2.4'
+__version__ = '0.3'
 
 builtin_markups = [MarkdownMarkup, ReStructuredTextMarkup]
 
