@@ -4,18 +4,17 @@
 
 from __future__ import absolute_import
 
+import os
 import sys
-from markups.common import *
+import markups.common as common
 from markups.abstract import AbstractMarkup
 
-MATHJAX_CONFIG = '''
-<script type="text/x-mathjax-config">
+MATHJAX_CONFIG = \
+'''<script type="text/x-mathjax-config">
 MathJax.Hub.Config({
-  tex2jax: {
-    inlineMath: [ ["$", "$"], ["\\\\(", "\\\\)"] ],
-    processEscapes: true,
-    processClass: "math"
-  },
+  config: ["MMLorHTML.js"],
+  jax: ["input/TeX", "output/HTML-CSS", "output/NativeMML"],
+  extensions: ["MathMenu.js", "MathZoom.js"],
   TeX: {
     equationNumbers: {autoNumber: "AMS"}
   }
@@ -27,9 +26,9 @@ class MarkdownMarkup(AbstractMarkup):
 	"""Markdown language"""
 	name = 'Markdown'
 	attributes = {
-		LANGUAGE_HOME_PAGE: 'http://daringfireball.net/projects/markdown/',
-		MODULE_HOME_PAGE: 'https://github.com/Waylan/Python-Markdown/',
-		SYNTAX_DOCUMENTATION: 'http://daringfireball.net/projects/markdown/syntax'
+		common.LANGUAGE_HOME_PAGE: 'http://daringfireball.net/projects/markdown/',
+		common.MODULE_HOME_PAGE: 'https://github.com/Waylan/Python-Markdown/',
+		common.SYNTAX_DOCUMENTATION: 'http://daringfireball.net/projects/markdown/syntax'
 	}
 	
 	file_extensions = ('.md', '.mkd', '.mkdn', '.mdwn', '.mdown', '.markdown')
@@ -66,24 +65,27 @@ class MarkdownMarkup(AbstractMarkup):
 	
 	def _get_mathjax_patterns(self, markdown):
 		def handle_match_inline(m):
-			node = markdown.util.etree.Element('span')
-			node.set('class', 'math')
-			node.text = markdown.util.AtomicString(m.group(2) + m.group(3) + m.group(4))
+			node = markdown.util.etree.Element('script')
+			node.set('type', 'math/tex')
+			node.text = markdown.util.AtomicString(m.group(3))
 			return node
 		
 		def handle_match(m):
-			node = markdown.util.etree.Element('div')
-			node.set('class', 'math')
-			node.text = markdown.util.AtomicString(m.group(2) + m.group(3) + m.group(4))
+			node = markdown.util.etree.Element('script')
+			node.set('type', 'math/tex; mode=display')
+			node.text = markdown.util.AtomicString(m.group(3))
+			if '\\begin' in m.group(2):
+				node.text = markdown.util.AtomicString(m.group(2) +
+				m.group(3) + m.group(4))
 			return node
 		
 		inlinemathpatterns = (
 			markdown.inlinepatterns.Pattern(r'(?<!\\|\$)(\$)([^\$]+)(\$)'),
-			markdown.inlinepatterns.Pattern(r'(?<!\\)(\\\()([^\\)]+)(\\\))')
+			markdown.inlinepatterns.Pattern(r'(?<!\\)(\\\()(.+?)(\\\))')
 		)
 		mathpatterns = (
 			markdown.inlinepatterns.Pattern(r'(?<!\\)(\$\$)([^\$]+)(\$\$)'),
-			markdown.inlinepatterns.Pattern(r'(?<!\\)(\\\[)(.+)(\\\])'),
+			markdown.inlinepatterns.Pattern(r'(?<!\\)(\\\[)(.+?)(\\\])'),
 			markdown.inlinepatterns.Pattern(r'(?<!\\)(\\begin{[a-z]+\*?})(.+)(\\end{[a-z]+\*?})')
 		)
 		patterns = []
@@ -95,17 +97,20 @@ class MarkdownMarkup(AbstractMarkup):
 			patterns.append(pattern)
 		return patterns
 	
-	def __init__(self, filename=None):
+	def __init__(self, filename=None, extensions=None):
 		AbstractMarkup.__init__(self, filename)
 		import markdown
-		self.extensions = self._load_extensions_list_from_file(
-			os.path.join(CONFIGURATION_DIR, 'markdown-extensions.txt'))
-		local_directory = os.path.split(filename)[0] if filename else '.'
-		if not local_directory: local_directory = '.'
-		self.extensions += self._load_extensions_list_from_file(
-			os.path.join(local_directory, 'markdown-extensions.txt'))
-		# Remove duplicate entries
-		self.extensions = list(set(self.extensions))
+		if extensions is None:
+			self.extensions = self._load_extensions_list_from_file(
+				os.path.join(common.CONFIGURATION_DIR, 'markdown-extensions.txt'))
+			local_directory = os.path.split(filename)[0] if filename else '.'
+			if not local_directory: local_directory = '.'
+			self.extensions += self._load_extensions_list_from_file(
+				os.path.join(local_directory, 'markdown-extensions.txt'))
+			# Remove duplicate entries
+			self.extensions = list(set(self.extensions))
+		else:
+			self.extensions = extensions
 		# We have two virtual extensions
 		if 'remove_extra' in self.extensions:
 			self.extensions.remove('remove_extra')
@@ -120,10 +125,9 @@ class MarkdownMarkup(AbstractMarkup):
 				self.extensions.remove(extension)
 		self.md = markdown.Markdown(self.extensions, output_format='html4')
 		if self.mathjax:
-			self.body_tag = 'class="tex2jax_ignore"'
 			patterns = self._get_mathjax_patterns(markdown)
-			for i in range(len(patterns)):
-				self.md.inlinePatterns.add('mathjax%d' % i, patterns[i], '<escape')
+			for i, pattern in enumerate(patterns):
+				self.md.inlinePatterns.add('mathjax%d' % i, pattern, '<escape')
 	
 	def get_document_title(self, text):
 		if 'meta' not in self.extensions:
@@ -137,7 +141,7 @@ class MarkdownMarkup(AbstractMarkup):
 	
 	def get_stylesheet(self, text=''):
 		if 'codehilite' in self.extensions:
-			return get_pygments_stylesheet('.codehilite')
+			return common.get_pygments_stylesheet('.codehilite')
 		return ''
 	
 	def get_javascript(self, text='', webenv=False):
@@ -147,10 +151,10 @@ class MarkdownMarkup(AbstractMarkup):
 			body = self.cache['body']
 		else:
 			body = self.get_document_body(text)
-		if not 'class="math"' in body:
+		if not '<script type="math/tex' in body:
 			return ''
-		return ('<script type="text/javascript" src="' + get_mathjax_url(webenv)
-		+ '?config=TeX-AMS-MML_HTMLorMML"></script>' + MATHJAX_CONFIG)
+		return (MATHJAX_CONFIG + '<script type="text/javascript" src="'
+		+ common.get_mathjax_url(webenv) + '"></script>')
 	
 	def get_document_body(self, text):
 		self.md.reset()
