@@ -24,14 +24,17 @@ class ReStructuredTextTest(unittest.TestCase):
 		title_expected = 'Hello, world!'
 		self.assertEqual(text_expected, text)
 		self.assertEqual(text_expected, text_from_cache)
+		self.assertEqual(title_expected, title)
+		self.assertEqual(title_expected, title_from_cache)
 	
 	def test_mathjax_loading(self):
 		markup = ReStructuredTextMarkup()
 		self.assertEqual('', markup.get_javascript('Hello, world!'))
 		js = markup.get_javascript('Hello, :math:`2+2`!')
-		self.assertTrue('<script' in js)
+		self.assertIn('<script', js)
 		body = markup.get_document_body('Hello, :math:`2+2`!')
-		self.assertTrue('<span class="math">' in body and r'\(2+2\)</span>' in body)
+		self.assertIn('<span class="math">', body)
+		self.assertIn(r'\(2+2\)</span>', body)
 
 if __name__ == '__main__':
 	unittest.main()
